@@ -32,8 +32,8 @@ function val = __get__ (sys, prop)
       val = sys.w;
 
     otherwise
-      error ("frd: get: invalid property name");
+      error ("frd: get: invalid property name '%s'", prop);
 
   endswitch
 
-endfunction
\ No newline at end of file
+endfunction
