@@ -16,8 +16,8 @@
 ## along with LTI Syncope.  If not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{sys} =} append (@var{sys1}, @var{sys2})
-## Group LTI models by appending their inputs and outputs.
+## @deftypefn {Function File} {@var{sys} =} append (@var{sys1}, @var{sys2}, @dots{}, @var{sysN})
+## Group @acronym{LTI} models by appending their inputs and outputs.
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
@@ -34,4 +34,4 @@ function sys = append (varargin)
     endfor
   endif
 
-endfunction
\ No newline at end of file
+endfunction
