@@ -18,10 +18,33 @@
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{bool} =} isminimumphase (@var{sys})
 ## @deftypefnx {Function File} {@var{bool} =} isminimumphase (@var{sys}, @var{tol})
-## Determine whether LTI system is minimum phase.
+## Determine whether @acronym{LTI} system is minimum phase.
 ## The zeros must lie in the left complex half-plane.
 ## The name minimum-phase refers to the fact that such a system has the
 ## minimum possible phase lag for the given magnitude response |sys(jw)|.
+##
+## @strong{Inputs}
+## @table @var
+## @item sys
+## @acronym{LTI} system.
+## @item tol
+## Optional tolerance.  Default value is 0.
+## @end table
+##
+## @strong{Outputs}
+## @table @var
+## @item bool = 0
+## System is not minimum phase.
+## @item bool = 1
+## System is minimum phase.
+## @end table
+##
+## @example
+## @group
+##   real (z) < -tol*(1 + abs (z))    continuous-time
+##   abs (z) < 1 - tol                discrete-time
+## @end group
+## @end example
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
@@ -39,4 +62,4 @@ function bool = isminimumphase (sys, tol = 0)
 
   bool = __is_stable__ (z, ct, tol);
 
-endfunction
\ No newline at end of file
+endfunction
