@@ -18,7 +18,30 @@
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{bool} =} isstable (@var{sys})
 ## @deftypefnx {Function File} {@var{bool} =} isstable (@var{sys}, @var{tol})
-## Determine whether LTI system is stable.
+## Determine whether @acronym{LTI} system is stable.
+##
+## @strong{Inputs}
+## @table @var
+## @item sys
+## @acronym{LTI} system.
+## @item tol
+## Optional tolerance for stability.  Default value is 0.
+## @end table
+##
+## @strong{Outputs}
+## @table @var
+## @item bool = 0
+## System is not stable.
+## @item bool = 1
+## System is stable.
+## @end table
+##
+## @example
+## @group
+##   real (p) < -tol*(1 + abs (p))    continuous-time
+##   abs (p) < 1 - tol                discrete-time
+## @end group
+## @end example
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
@@ -31,9 +54,9 @@ function bool = isstable (sys, tol = 0)
     print_usage ();
   endif
 
-  eigw = pole (sys);
+  pol = pole (sys);
   ct = isct (sys);
 
-  bool = __is_stable__ (eigw, ct, tol);
+  bool = __is_stable__ (pol, ct, tol);
 
-endfunction
\ No newline at end of file
+endfunction
