@@ -17,12 +17,12 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{p} =} pole (@var{sys})
-## Compute poles of LTI system.
+## Compute poles of @acronym{LTI} system.
 ##
 ## @strong{Inputs}
 ## @table @var
 ## @item sys
-## LTI model.
+## @acronym{LTI} model.
 ## @end table
 ##
 ## @strong{Outputs}
@@ -30,6 +30,16 @@
 ## @item p
 ## Poles of @var{sys}.
 ## @end table
+##
+## @strong{Algorithm}@*
+## For (descriptor) state-space models, @command{pole}
+## relies on Octave's @command{eig}.
+## For @acronym{SISO} transfer functions, @command{pole}
+## uses Octave's @command{roots}.
+## @acronym{MIMO} transfer functions are converted to
+## a @emph{minimal} state-space representation for the
+## computation of the poles.
+##
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
