@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010, 2011, 2012   Lukas F. Reichlin
+## Copyright (C) 2009, 2010, 2011, 2012, 2013   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -20,9 +20,9 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: October 2009
-## Version: 0.5
+## Version: 0.6
 
-function H = __freqresp__ (sys, w, resptype = 0, cellflag = false)
+function H = __freqresp__ (sys, w, cellflag = false)
 
   if (sys.scaled == false)
     sys = prescale (sys);
@@ -30,37 +30,16 @@ function H = __freqresp__ (sys, w, resptype = 0, cellflag = false)
 
   [a, b, c, d, e, tsam] = dssdata (sys);
 
-  if (resptype != 0 && columns (b) != rows (c))
-    error ("ss: freqresp: system must be square for response type %d", resptype);
-  endif
-
   if (isct (sys))  # continuous system
     s = i * w;
   else             # discrete system
     s = exp (i * w * abs (tsam));
   endif
 
-  switch (resptype)
-    case 0         # default system
-      H = arrayfun (@(x) c/(x*e - a)*b + d, s, "uniformoutput", false);
-
-    case 1         # inversed system
-      H = arrayfun (@(x) inv (c/(x*e - a)*b + d), s, "uniformoutput", false);
-
-    case 2         # inversed sensitivity
-      j = eye (columns (b));
-      H = arrayfun (@(x) j + c/(x*e - a)*b + d, s, "uniformoutput", false);
-
-    case 3         # inversed complementary sensitivity
-      j = eye (columns (b));
-      H = arrayfun (@(x) j + inv (c/(x*e - a)*b + d), s, "uniformoutput", false);
-
-    otherwise
-      error ("ss: freqresp: invalid response type");
-  endswitch
+  H = arrayfun (@(x) c/(x*e - a)*b + d, s, "uniformoutput", false);
 
   if (! cellflag)
     H = cat (3, H{:});
   endif
 
-endfunction
\ No newline at end of file
+endfunction
