@@ -1,4 +1,4 @@
-## Copyright (C) 2009   Lukas F. Reichlin
+## Copyright (C) 2009, 2012   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -20,7 +20,7 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: October 2009
-## Version: 0.1
+## Version: 0.2
 
 function sys = __set__ (sys, prop, val)
 
@@ -35,15 +35,24 @@ function sys = __set__ (sys, prop, val)
       __tf_dim__ (sys.num, den);
       sys.den = den;
 
-    case {"tfvar", "variable"}
+    case {"tfvar", "variable", "var"}
       if (ischar (val))
         sys.tfvar = val;
       else
         error ("tf: set: invalid transfer function variable");
       endif
 
+    case "inv"
+      if (! isdt (sys))
+        error ("tf: set: property 'inv' requires discrete-time system");
+      elseif (! isscalar (val))
+        error ("tf: set: property 'inv' must be a scalar logical");
+      else
+        sys.inv = logical (val);
+      endif
+
     otherwise
-      error ("tf: set: invalid property name");
+      error ("tf: set: invalid property name '%s'", prop);
 
   endswitch
 
